isRequired property
Whether the page needs a value: the parameter is required, non-nullable, has no default and is not a PageArgKind.flag.
Implementation
final bool isRequired;
Whether the page needs a value: the parameter is required, non-nullable, has no default and is not a PageArgKind.flag.
final bool isRequired;