PageArgs class abstract interface

A generated *Args class: page arguments that serialize into route arguments.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArguments() Map<String, String>
The route arguments that PageArgsSchema.tryParse reads back.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited