PageArgKind enum
How the value of a generated route argument is written.
Values
- integer → const PageArgKind
-
An
int. - decimal → const PageArgKind
-
A
double. - number → const PageArgKind
-
A
num. - bigInteger → const PageArgKind
-
A
BigInt. - text → const PageArgKind
-
A
String. - flag → const PageArgKind
-
A
bool, written astrueorfalse. - dateTime → const PageArgKind
-
A
DateTime, written in ISO 8601. - uri → const PageArgKind
-
A
Uri. - choice → const PageArgKind
-
An enum value, written as its
name. - list → const PageArgKind
-
A
ListorIterable, written as comma-separated values.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PageArgKind> - A constant List of the values in this enum, in order of their declaration.